pub struct ExtremesDetector<'a, 'd, T, M>where
T: Instance,
M: FilterMarker,{ /* private fields */ }Expand description
Extremes (min/max) detector of a filter.
Implementations
Sourceimpl<'a, 'd, T, M> ExtremesDetector<'a, 'd, T, M>where
T: Instance,
M: FilterMarker,
impl<'a, 'd, T, M> ExtremesDetector<'a, 'd, T, M>where
T: Instance,
M: FilterMarker,
Sourcepub fn assign_transceivers<const N: usize>(
&mut self,
transceivers: [&dyn TransceiverTrait<T, Enabled>; N],
)
pub fn assign_transceivers<const N: usize>( &mut self, transceivers: [&dyn TransceiverTrait<T, Enabled>; N], )
Assign provided transceivers to this extremes detector
Sourcepub fn read_maxima(&mut self) -> ResultExtreme
pub fn read_maxima(&mut self) -> ResultExtreme
Reads the extremes detector maximum value and its corresponding channel.
Reading this resets the register value to 0x800000 and clears the
channel field.
Sourcepub fn read_minima(&mut self) -> ResultExtreme
pub fn read_minima(&mut self) -> ResultExtreme
Reads the extremes detector minimum value and its corresponding channel.
Reading this resets the register value to 0x7FFFFF and clears the
channel field.